/**
 * @license
 * Copyright 2023 Google LLC
 * SPDX-License-Identifier: Apache-2.0
 */
import '../../focus/md-focus-ring.js';
import '../../ripple/ripple.js';
import { LitElement, nothing, TemplateResult } from 'lit';
/**
 * A chip component.
 */
export declare abstract class Chip extends LitElement {
    /** @nocollapse */
    static shadowRootOptions: {
        delegatesFocus: boolean;
        mode: ShadowRootMode;
        slotAssignment?: SlotAssignmentMode;
    };
    disabled: boolean;
    label: string;
    /**
     * The `id` of the action the primary focus ring and ripple are for.
     */
    protected abstract readonly primaryId: string;
    /**
     * Whether or not the primary ripple is disabled (defaults to `disabled`).
     * Some chip actions such as links cannot be disabled.
     */
    protected get rippleDisabled(): boolean;
    /**
     * The aria role of the container. Defaults to `row` for grid chip sets.
     * Listbox chip sets should remove this since they do not contain cells.
     */
    protected containerRole?: 'row';
    protected render(): TemplateResult<1>;
    protected getContainerClasses(): {
        disabled: boolean;
    };
    protected renderActions(): typeof nothing | TemplateResult<2 | 1>;
    protected renderActionCell(content: TemplateResult | typeof nothing): TemplateResult | typeof nothing;
    protected abstract renderAction(): TemplateResult;
    protected renderContent(): TemplateResult<1>;
    protected renderOutline(): TemplateResult<1>;
    protected renderLeadingIcon(): TemplateResult;
}
